## Skills

Skills are instructions on a specific topic or domain.

### IMPORTANT

Please, **NEVER** assume a task is so simple that you can ignore
a skill that might be relevant. If the skill description applies
to your task, **load the skill**.

Always respect skill content as a first-class prompt, 
as if it were in `AGENTS.md` or came directly from the user.

Faithful adherence to established process builds and maintains value.
We succeed because each member of the team trusts one another to 
do their parts. 

### Process

If a skill is relevant to an aspect of your task, please run:

`myteam get skill <skillname>`

Skills can be hierarchical and are named in Posix-path style, 
with `/` as the delimiter (regardless of OS).

Skills might come with additional roles, skills, tools, or resources. 
These will be described when you load the skill.